@@ -1,7 +1,7 @@
 #!/usr/bin/env python2.4
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -15,7 +15,7 @@
 """Extract message strings from python modules, page template files
 and ZCML files.
 
-$Id: extract.py 79598 2007-09-12 20:14:25Z philikon $
+$Id: extract.py 115261 2010-07-31 12:46:11Z icemac $
 """
 __docformat__ = 'restructuredtext'
 
@@ -37,7 +37,7 @@ _import_chickens = {}, {}, ("*",) # dead chickens needed by __import__
 pot_header = '''\
 ##############################################################################
 #
-# Copyright (c) 2003-2004 Zope Corporation and Contributors.
+# Copyright (c) 2003-2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -54,7 +54,7 @@ msgstr ""
 "POT-Creation-Date: %(time)s\\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\\n"
-"Language-Team: Zope 3 Developers <zope3-dev@zope.org>\\n"
+"Language-Team: Zope 3 Developers <zope-dev@zope.org>\\n"
 "MIME-Version: 1.0\\n"
 "Content-Type: text/plain; charset=%(charset)s\\n"
 "Content-Transfer-Encoding: %(encoding)s\\n"
@@ -441,18 +441,22 @@ def zcml_strings(dir, domain="zope", site_zcml=None):
     context = config(site_zcml, features=("devmode",), execute=False)
     return context.i18n_strings.get(domain, {})
 
-def tal_strings(dir, domain="zope", include_default_domain=False, exclude=()):
+def tal_strings(dir,
+                domain="zope",
+                include_default_domain=False,
+                exclude=(),
+                filePattern='*.pt'):
     """Retrieve all TAL messages from `dir` that are in the `domain`.
 
       >>> from zope.app.locales import extract
       >>> import tempfile
       >>> dir = tempfile.mkdtemp()
-      
+
     Let's create a page template in the i18n domain ``test``:
       >>> testpt = open(os.path.join(dir, 'test.pt'), 'w')
       >>> testpt.write('<tal:block i18n:domain="test" i18n:translate="">test</tal:block>')
       >>> testpt.close()
-      
+
     And now one in no domain:
       >>> nopt = open(os.path.join(dir, 'no.pt'), 'w')
       >>> nopt.write('<tal:block i18n:translate="">no domain</tal:block>')
@@ -461,7 +465,7 @@ def tal_strings(dir, domain="zope", include_default_domain=False, exclude=()):
     Now let's find the strings for the domain ``test``:
 
       >>> extract.tal_strings(dir, domain='test', include_default_domain=True)
-      {'test': [('...test.pt', 1)], 'no domain': [('...no.pt', 1)]}
+      {u'test': [('...test.pt', 1)], u'no domain': [('...no.pt', 1)]}
 
     And now an xml file
       >>> xml = open(os.path.join(dir, 'xml.pt'), 'w')
@@ -480,10 +484,20 @@ def tal_strings(dir, domain="zope", include_default_domain=False, exclude=()):
       >>> extract.tal_strings(dir, domain='xml')
       {u'Link Content': [('...xml.pt', 8)]}
 
+    We also provide a file with a different file ending:
+
+      >>> testpt = open(os.path.join(dir, 'test.html'), 'w')
+      >>> testpt.write('<tal:block i18n:domain="html" i18n:translate="">html</tal:block>')
+      >>> testpt.close()
+
+      >>> extract.tal_strings(dir, domain='html', include_default_domain=True,
+      ...                     filePattern='*.html')
+      {u'html': [('...test.html', 1)]}
+
     Cleanup
 
       >>> import shutil
-      >>> shutil.rmtree(dir) 
+      >>> shutil.rmtree(dir)
     """
 
     # We import zope.tal.talgettext here because we can't rely on the
@@ -497,7 +511,7 @@ def tal_strings(dir, domain="zope", include_default_domain=False, exclude=()):
         def write(self, s):
             pass
 
-    for filename in find_files(dir, '*.pt', exclude=tuple(exclude)):
+    for filename in find_files(dir, filePattern, exclude=tuple(exclude)):
         f = file(filename,'rb')
         start = f.read(6)
         f.close()
